
<p align="center">
<img src="https://raw.githubusercontent.com/coiled/logos/master/Coiled-Logo_Horizontal_Black-RGB.png" width="200" style="max-width: 200px;" alt="Coiled">
</p>

<p align="center">
  <a href="https://coiled.io">Coiled.io</a> •
  <a href="https://docs.coiled.io/user_guide/index.html">Documentation</a> •
  <a href="https://join.slack.com/t/coiled-users/shared_invite/zt-hx1fnr7k-In~Q8ui3XkQfvQon0yN5WQ">Community</a> •
  <a href="https://docs.coiled.io/user_guide/support.html">Support</a>
</p>

Coiled is a deployment-as-a-service library for scaling Python with Dask, a popular open source library for parallel analytics. Coiled manages cloud resources, networking, software environments, and everything you need to scale Python in the cloud robustly and easily.

Go to https://cloud.coiled.io to get started with Coiled.
